:icon: material/map-marker-outline

Station
=======

Managing the instrument station setup is an important part of measurements.
The stationing commands can be used to manage various aspects of a setup.

.. toctree::
    :maxdepth: 1

    calc
    upload
